@@ -31,18 +31,12 @@ test_that("custom aggregators translated correctly", {
   local_con(simulate_teradata())
 
   expect_equal(translate_sql(var(x, na.rm = TRUE), window = FALSE), sql("VAR_SAMP(`x`)"))
-
-  expect_error(translate_sql(cor(x), window = FALSE), "not available")
-  expect_error(translate_sql(cov(x), window = FALSE), "not available")
 })
 
 test_that("custom window functions translated correctly", {
   local_con(simulate_teradata())
 
   expect_equal(translate_sql(var(x, na.rm = TRUE)), sql("VAR_SAMP(`x`) OVER ()"))
-
-  expect_error(translate_sql(cor(x)), "not supported")
-  expect_error(translate_sql(cov(x)), "not supported")
 })
 
 test_that("generates custom sql", {
