@@ -1,4 +1,5 @@
 test_that("two arranges equivalent to one", {
+  skip("not clear whether test makes sense")
   mf <- memdb_frame(x = c(2, 2, 1), y = c(1, -1, 1))
 
   mf1 <- mf %>% arrange(x, y)
@@ -10,7 +11,7 @@ test_that("two arranges equivalent to one", {
 # sql_render --------------------------------------------------------------
 
 test_that("quoting for rendering ordered grouped table", {
-  db <- memdb_frame(x = 1, y = 2, .name = "test-verb-arrange")
+  db <- copy_to_test("sqlite", tibble(x = 1, y = 2), name = "test-verb-arrange")
   out <- db %>% group_by(x) %>% arrange(y) %>% ungroup()
   expect_snapshot(sql_render(out))
   expect_equal(collect(out), tibble(x = 1, y = 2))
@@ -76,6 +77,11 @@ test_that("can combine arrange with dual table verbs", {
   })
 })
 
+test_that("only add step if necessary", {
+  lf <- lazy_frame(x = 1:3, y = 1:3)
+  expect_equal(lf %>% arrange(), lf)
+})
+
 # sql_build ---------------------------------------------------------------
 
 test_that("arrange generates order_by", {
@@ -122,10 +128,10 @@ test_that("arranges captures DESC", {
 })
 
 test_that("multiple arranges combine", {
+  skip("not clear whether test makes sense")
   out <- lazy_frame(x = 1:3, y = 3:1) %>% arrange(x) %>% arrange(y)
   out <- arrange(arrange(lazy_frame(x = 1:3, y = 3:1), x), y)
 
   sort <- lapply(op_sort(out), get_expr)
   expect_equal(sort, list(quote(x), quote(y)))
 })
-
